@@ -51,7 +51,7 @@ def should_save_readability(link: Link, out_dir: Optional[str]=None) -> bool:
         return False
 
     output = Path(out_dir or link.link_dir) / 'readability'
-    return SAVE_READABILITY and (not output.exists())
+    return SAVE_READABILITY and READABILITY_VERSION and (not output.exists())
 
 
 @enforce_types
