@@ -63,7 +63,7 @@ def merge_links(a: Link, b: Link) -> Link:
     """deterministially merge two links, favoring longer field values over shorter,
     and "cleaner" values over worse ones.
     """
-    assert a.base_url == b.base_url, 'Cannot merge two links with different URLs'
+    assert a.base_url == b.base_url, f'Cannot merge two links with different URLs ({a.base_url} != {b.base_url})'
 
     # longest url wins (because a fuzzy url will always be shorter)
     url = a.url if len(a.url) > len(b.url) else b.url
@@ -129,7 +129,7 @@ def validate_links(links: Iterable[Link]) -> List[Link]:
     try:
         links = archivable_links(links)  # remove chrome://, about:, mailto: etc.
         links = sorted_links(links)      # deterministically sort the links based on timstamp, url
-        links = uniquefied_links(links)  # merge/dedupe duplicate timestamps & urls
+        links = fix_duplicate_links(links)  # merge/dedupe duplicate timestamps & urls
     finally:
         timer.end()
 
@@ -144,34 +144,39 @@ def archivable_links(links: Iterable[Link]) -> Iterable[Link]:
             urlparse(link.url)
         except ValueError:
             continue
-        scheme_is_valid = scheme(link.url) in ('http', 'https', 'ftp')
-        not_blacklisted = (not URL_BLACKLIST_PTN.match(link.url)) if URL_BLACKLIST_PTN else True
-        if scheme_is_valid and not_blacklisted:
-            yield link
+        if scheme(link.url) not in ('http', 'https', 'ftp'):
+            continue
+        if URL_BLACKLIST_PTN and URL_BLACKLIST_PTN.search(link.url):
+            continue
+
+        yield link
 
 
 @enforce_types
-def uniquefied_links(sorted_links: Iterable[Link]) -> Iterable[Link]:
+def fix_duplicate_links(sorted_links: Iterable[Link]) -> Iterable[Link]:
     """
     ensures that all non-duplicate links have monotonically increasing timestamps
     """
+    # from core.models import Snapshot
 
     unique_urls: OrderedDict[str, Link] = OrderedDict()
 
     for link in sorted_links:
-        if link.base_url in unique_urls:
+        if link.url in unique_urls:
             # merge with any other links that share the same url
-            link = merge_links(unique_urls[link.base_url], link)
-        unique_urls[link.base_url] = link
+            link = merge_links(unique_urls[link.url], link)
+        unique_urls[link.url] = link
 
-    unique_timestamps: OrderedDict[str, Link] = OrderedDict()
-    for link in unique_urls.values():
-        new_link = link.overwrite(
-            timestamp=lowest_uniq_timestamp(unique_timestamps, link.timestamp),
-        )
-        unique_timestamps[new_link.timestamp] = new_link
+    # unique_timestamps: OrderedDict[str, Link] = OrderedDict()
+    # for link in unique_urls.values():
+    #     closest_non_duplicate_ts = lowest_uniq_timestamp(unique_timestamps, link.timestamp)
+    #     if closest_non_duplicate_ts != link.timestamp:
+    #         link = link.overwrite(timestamp=closest_non_duplicate_ts)
+    #         Snapshot.objects.filter(url=link.url).update(timestamp=link.timestamp)
+    #     unique_timestamps[link.timestamp] = link
 
-    return unique_timestamps.values()
+    # return unique_timestamps.values()
+    return unique_urls.values()
 
 
 @enforce_types
@@ -236,16 +241,23 @@ def write_main_index(links: List[Link], out_dir: str=OUTPUT_DIR, finished: bool=
 
     log_indexing_process_started(len(links))
 
-    with timed_index_update(os.path.join(out_dir, SQL_INDEX_FILENAME)):
-        write_sql_main_index(links, out_dir=out_dir)
-        os.chmod(os.path.join(out_dir, SQL_INDEX_FILENAME), int(OUTPUT_PERMISSIONS, base=8)) # set here because we don't write it with atomic writes
+    try:
+        with timed_index_update(os.path.join(out_dir, SQL_INDEX_FILENAME)):
+            write_sql_main_index(links, out_dir=out_dir)
+            os.chmod(os.path.join(out_dir, SQL_INDEX_FILENAME), int(OUTPUT_PERMISSIONS, base=8)) # set here because we don't write it with atomic writes
 
+        with timed_index_update(os.path.join(out_dir, JSON_INDEX_FILENAME)):
+            write_json_main_index(links, out_dir=out_dir)
 
-    with timed_index_update(os.path.join(out_dir, JSON_INDEX_FILENAME)):
-        write_json_main_index(links, out_dir=out_dir)
-
-    with timed_index_update(os.path.join(out_dir, HTML_INDEX_FILENAME)):
-        write_html_main_index(links, out_dir=out_dir, finished=finished)
+        with timed_index_update(os.path.join(out_dir, HTML_INDEX_FILENAME)):
+            write_html_main_index(links, out_dir=out_dir, finished=finished)
+    except (KeyboardInterrupt, SystemExit):
+        stderr('[!] Warning: Still writing index to disk...', color='lightyellow')
+        stderr('    Run archivebox init to fix any inconsisntencies from an ungraceful exit.')
+        with timed_index_update(os.path.join(out_dir, SQL_INDEX_FILENAME)):
+            write_sql_main_index(links, out_dir=out_dir)
+            os.chmod(os.path.join(out_dir, SQL_INDEX_FILENAME), int(OUTPUT_PERMISSIONS, base=8)) # set here because we don't write it with atomic writes
+        raise SystemExit(0)
 
     log_indexing_process_finished()
 
@@ -255,13 +267,29 @@ def load_main_index(out_dir: str=OUTPUT_DIR, warn: bool=True) -> List[Link]:
     """parse and load existing index with any new links from import_path merged in"""
 
     all_links: List[Link] = []
-    all_links = list(parse_json_main_index(out_dir))
-    links_from_sql = list(parse_sql_main_index(out_dir))
+    try:
+        all_links = list(parse_json_main_index(out_dir))
+        links_from_sql = list(parse_sql_main_index(out_dir))
 
-    if warn and not set(l.url for l in all_links) == set(l.url for l in links_from_sql):
-        stderr('{red}[!] Warning: SQL index does not match JSON index!{reset}'.format(**ANSI))
-        stderr('    To repair the index and re-import any orphaned links run:')
-        stderr('        archivebox init')
+        json_urls = set(l.url for l in all_links)
+        sql_urls = set(l.url for l in links_from_sql)
+        only_in_sql = sql_urls - json_urls
+        only_in_json = json_urls - sql_urls
+
+        if only_in_json:
+            stderr('{red}[!] Warning: SQL index does not match JSON index!{reset}'.format(**ANSI))
+            if only_in_json:
+                stderr('    > Only in JSON: {}...'.format(', '.join(list(only_in_json)[:5])))
+            if only_in_sql:
+                stderr('    > Only in SQL: {}...'.format(', '.join(list(only_in_sql)[:5])))
+
+            stderr('    To repair the index and re-import any orphaned links run:')
+            stderr('        archivebox init')
+        if only_in_sql:
+            # meh, this harmless, it'll get overwritten on next run anyway
+            pass
+    except (KeyboardInterrupt, SystemExit):
+        raise SystemExit(0)
 
     return all_links
 
@@ -278,14 +306,14 @@ def load_main_index_meta(out_dir: str=OUTPUT_DIR) -> Optional[dict]:
 
 
 @enforce_types
-def parse_links_from_source(source_path: str) -> Tuple[List[Link], List[Link]]:
+def parse_links_from_source(source_path: str, root_url: Optional[str]=None) -> Tuple[List[Link], List[Link]]:
 
     from ..parsers import parse_links
 
     new_links: List[Link] = []
 
     # parse and validate the import file
-    raw_links, parser_name = parse_links(source_path)
+    raw_links, parser_name = parse_links(source_path, root_url=root_url)
     new_links = validate_links(raw_links)
 
     if parser_name:
