@@ -55,6 +55,7 @@ from .index.html import parse_html_main_index
 from .extractors import archive_links, archive_link, ignore_methods
 from .config import (
     stderr,
+    hint,
     ConfigDict,
     ANSI,
     IS_TTY,
@@ -169,7 +170,7 @@ def help(out_dir: str=OUTPUT_DIR) -> None:
     archivebox add --depth=1 ~/Downloads/bookmarks_export.html
     
     archivebox list --sort=timestamp --csv=timestamp,url,is_archived
-    archivebox schedule --every=week https://example.com/some/feed.rss
+    archivebox schedule --every=day https://example.com/some/feed.rss
     archivebox update --resume=15109948213.123
 
 {lightred}Documentation:{reset}
@@ -522,11 +523,16 @@ def add(urls: Union[str, List[str]],
         depth: int=0,
         update_all: bool=not ONLY_NEW,
         index_only: bool=False,
+        overwrite: bool=False,
+        init: bool=False,
         out_dir: str=OUTPUT_DIR) -> List[Link]:
     """Add a new URL or list of URLs to your archive"""
 
     assert depth in (0, 1), 'Depth must be 0 or 1 (depth >1 is not supported yet)'
 
+    if init:
+        run_subcommand('init', stdin=None, pwd=out_dir)
+
     # Load list of links from the existing index
     check_data_folder(out_dir=out_dir)
     check_dependencies()
@@ -542,29 +548,37 @@ def add(urls: Union[str, List[str]],
         # save verbatim args to sources
         write_ahead_log = save_text_as_source('\n'.join(urls), filename='{ts}-import.txt', out_dir=out_dir)
     
-    new_links += parse_links_from_source(write_ahead_log)
+    new_links += parse_links_from_source(write_ahead_log, root_url=None)
 
     # If we're going one level deeper, download each link and look for more links
     new_links_depth = []
     if new_links and depth == 1:
         log_crawl_started(new_links)
         for new_link in new_links:
-            downloaded_file = save_file_as_source(new_link.url, filename='{ts}-crawl-{basename}.txt', out_dir=out_dir)
-            new_links_depth += parse_links_from_source(downloaded_file)
-    all_links, new_links = dedupe_links(all_links, new_links + new_links_depth)
+            downloaded_file = save_file_as_source(new_link.url, filename=f'{new_link.timestamp}-crawl-{new_link.domain}.txt', out_dir=out_dir)
+            new_links_depth += parse_links_from_source(downloaded_file, root_url=new_link.url)
+
+    imported_links = list({link.url: link for link in (new_links + new_links_depth)}.values())
+    all_links, new_links = dedupe_links(all_links, imported_links)
     write_main_index(links=all_links, out_dir=out_dir, finished=not new_links)
 
     if index_only:
         return all_links
 
     # Run the archive methods for each link
-    to_archive = all_links if update_all else new_links
-    archive_links(to_archive, out_dir=out_dir)
+    if update_all:
+        archive_links(all_links, overwrite=overwrite, out_dir=out_dir)
+    elif overwrite:
+        archive_links(imported_links, overwrite=True, out_dir=out_dir)
+    elif new_links:
+        archive_links(new_links, overwrite=False, out_dir=out_dir)
+    else:
+        # nothing was updated, don't bother re-saving the index
+        return all_links
 
     # Step 4: Re-write links index with updated titles, icons, and resources
-    if to_archive:
-        all_links = load_main_index(out_dir=out_dir)
-        write_main_index(links=list(all_links), out_dir=out_dir, finished=True)
+    all_links = load_main_index(out_dir=out_dir)
+    write_main_index(links=list(all_links), out_dir=out_dir, finished=True)
     return all_links
 
 @enforce_types
@@ -596,8 +610,8 @@ def remove(filter_str: Optional[str]=None,
                 color='red',
             )
             stderr()
-            stderr('    {lightred}Hint:{reset} To remove all urls you can run:'.format(**ANSI))
-            stderr("        archivebox remove --filter-type=regex '.*'")
+            hint(('To remove all urls you can run:',
+                  'archivebox remove --filter-type=regex ".*"'))
             stderr()
             raise SystemExit(2)
         elif filter_str:
@@ -697,6 +711,16 @@ def update(resume: Optional[float]=None,
         
     # Step 3: Run the archive methods for each link
     to_archive = new_links if only_new else all_links
+    if resume:
+        to_archive = [
+            link for link in to_archive
+            if link.timestamp >= str(resume)
+        ]
+        if not to_archive:
+            stderr('')
+            stderr(f'[√] Nothing found to resume after {resume}', color='green')
+            return all_links
+
     archive_links(to_archive, overwrite=overwrite, out_dir=out_dir)
 
     # Step 4: Re-write links index with updated titles, icons, and resources
@@ -922,8 +946,15 @@ def schedule(add: bool=False,
     cron = CronTab(user=True)
     cron = dedupe_cron_jobs(cron)
 
+    if clear:
+        print(cron.remove_all(comment=CRON_COMMENT))
+        cron.write()
+        raise SystemExit(0)
+
     existing_jobs = list(cron.find_comment(CRON_COMMENT))
-    if every:
+
+    if every or add:
+        every = every or 'day'
         quoted = lambda s: f'"{s}"' if s and ' ' in s else s
         cmd = [
             'cd',
@@ -931,21 +962,21 @@ def schedule(add: bool=False,
             '&&',
             quoted(ARCHIVEBOX_BINARY),
             *(['add', f'--depth={depth}', f'"{import_path}"'] if import_path else ['update']),
-            '2>&1',
             '>',
             quoted(os.path.join(LOGS_DIR, 'archivebox.log')),
+            '2>&1',
 
         ]
         new_job = cron.new(command=' '.join(cmd), comment=CRON_COMMENT)
 
-        if every in ('minute', 'hour', 'day', 'week', 'month', 'year'):
+        if every in ('minute', 'hour', 'day', 'month', 'year'):
             set_every = getattr(new_job.every(), every)
             set_every()
         elif CronSlices.is_valid(every):
             new_job.setall(every)
         else:
             stderr('{red}[X] Got invalid timeperiod for cron task.{reset}'.format(**ANSI))
-            stderr('    It must be one of minute/hour/day/week/month')
+            stderr('    It must be one of minute/hour/day/month')
             stderr('    or a quoted cron-format schedule like:')
             stderr('        archivebox init --every=day https://example.com/some/rss/feed.xml')
             stderr('        archivebox init --every="0/5 * * * *" https://example.com/some/rss/feed.xml')
@@ -977,11 +1008,6 @@ def schedule(add: bool=False,
             stderr('        archivebox schedule --every=[timeperiod] https://example.com/some/rss/feed.xml')
         raise SystemExit(0)
 
-    elif clear:
-        print(cron.remove_all(comment=CRON_COMMENT))
-        cron.write()
-        raise SystemExit(0)
-
     cron = CronTab(user=True)
     cron = dedupe_cron_jobs(cron)
     existing_jobs = list(cron.find_comment(CRON_COMMENT))
@@ -996,10 +1022,11 @@ def schedule(add: bool=False,
         if run_all:
             try:
                 for job in existing_jobs:
-                    sys.stdout.write(f'  > {job.command}')
+                    sys.stdout.write(f'  > {job.command.split("/archivebox ")[0].split(" && ")[0]}\n')
+                    sys.stdout.write(f'    > {job.command.split("/archivebox ")[-1].split(" > ")[0]}')
                     sys.stdout.flush()
                     job.run()
-                    sys.stdout.write(f'\r  √ {job.command}\n')
+                    sys.stdout.write(f'\r    √ {job.command.split("/archivebox ")[-1]}\n')
             except KeyboardInterrupt:
                 print('\n{green}[√] Stopped.{reset}'.format(**ANSI))
                 raise SystemExit(1)
@@ -1007,8 +1034,7 @@ def schedule(add: bool=False,
         if foreground:
             try:
                 for job in existing_jobs:
-                    sys.stdout.write(f'  > {job.command}')
-                    sys.stdout.flush()
+                    print(f'  > {job.command.split("/archivebox ")[-1].split(" > ")[0]}')
                 for result in cron.run_scheduler():
                     print(result)
             except KeyboardInterrupt:
@@ -1044,7 +1070,7 @@ def server(runserver_args: Optional[List[str]]=None,
 
     print('{green}[+] Starting ArchiveBox webserver...{reset}'.format(**ANSI))
     if admin_user:
-        print("{lightred}[i] The admin username is:{lightblue} {}{reset}".format(admin_user.username, **ANSI))
+        hint('The admin username is{lightblue} {}{reset}\n'.format(admin_user.username, **ANSI))
     else:
         print('{lightyellow}[!] No admin users exist yet, you will not be able to edit links in the UI.{reset}'.format(**ANSI))
         print()
