@@ -11,7 +11,7 @@ import re
 import os
 from io import StringIO
 
-from typing import IO, Tuple, List
+from typing import IO, Tuple, List, Optional
 from datetime import datetime
 
 from ..system import atomic_write
@@ -23,12 +23,14 @@ from ..config import (
 )
 from ..util import (
     basename,
+    htmldecode,
     download_url,
     enforce_types,
     URL_REGEX,
 )
 from ..index.schema import Link
 from ..logging_util import TimedProgress, log_source_saved
+
 from .pocket_html import parse_pocket_html_export
 from .pinboard_rss import parse_pinboard_rss_export
 from .shaarli_rss import parse_shaarli_rss_export
@@ -36,26 +38,29 @@ from .medium_rss import parse_medium_rss_export
 from .netscape_html import parse_netscape_html_export
 from .generic_rss import parse_generic_rss_export
 from .generic_json import parse_generic_json_export
+from .generic_html import parse_generic_html_export
 from .generic_txt import parse_generic_txt_export
 
 PARSERS = (
-        # Specialized parsers
-        ('Pocket HTML', parse_pocket_html_export),
-        ('Pinboard RSS', parse_pinboard_rss_export),
-        ('Shaarli RSS', parse_shaarli_rss_export),
-        ('Medium RSS', parse_medium_rss_export),
-        
-        # General parsers
-        ('Netscape HTML', parse_netscape_html_export),
-        ('Generic RSS', parse_generic_rss_export),
-        ('Generic JSON', parse_generic_json_export),
+    # Specialized parsers
+    ('Pocket HTML', parse_pocket_html_export),
+    ('Pinboard RSS', parse_pinboard_rss_export),
+    ('Shaarli RSS', parse_shaarli_rss_export),
+    ('Medium RSS', parse_medium_rss_export),
+    
+    # General parsers
+    ('Netscape HTML', parse_netscape_html_export),
+    ('Generic RSS', parse_generic_rss_export),
+    ('Generic JSON', parse_generic_json_export),
+    ('Generic HTML', parse_generic_html_export),
+
+    # Fallback parser
+    ('Plain Text', parse_generic_txt_export),
+)
 
-        # Fallback parser
-        ('Plain Text', parse_generic_txt_export),
-    )
 
 @enforce_types
-def parse_links_memory(urls: List[str]):
+def parse_links_memory(urls: List[str], root_url: Optional[str]=None):
     """
     parse a list of URLS without touching the filesystem
     """
@@ -66,17 +71,16 @@ def parse_links_memory(urls: List[str]):
     file = StringIO()
     file.writelines(urls)
     file.name = "io_string"
-    output = _parse(file, timer)
-
-    if output is not None:
-        return output
-
+    links, parser = run_parser_functions(file, timer, root_url=root_url)
     timer.end()
-    return [], 'Failed to parse'
+
+    if parser is None:
+        return [], 'Failed to parse'
+    return links, parser
     
 
 @enforce_types
-def parse_links(source_file: str) -> Tuple[List[Link], str]:
+def parse_links(source_file: str, root_url: Optional[str]=None) -> Tuple[List[Link], str]:
     """parse a list of URLs with their metadata from an 
        RSS feed, bookmarks export, or text file
     """
@@ -85,28 +89,39 @@ def parse_links(source_file: str) -> Tuple[List[Link], str]:
 
     timer = TimedProgress(TIMEOUT * 4)
     with open(source_file, 'r', encoding='utf-8') as file:
-        output = _parse(file, timer)
-
-    if output is not None:
-        return output
+        links, parser = run_parser_functions(file, timer, root_url=root_url)
 
     timer.end()
-    return [], 'Failed to parse'
+    if parser is None:
+        return [], 'Failed to parse'
+    return links, parser
+
+
+def run_parser_functions(to_parse: IO[str], timer, root_url: Optional[str]=None) -> Tuple[List[Link], Optional[str]]:
+    most_links: List[Link] = []
+    best_parser_name = None
 
-def _parse(to_parse: IO[str], timer) -> Tuple[List[Link], str]:
     for parser_name, parser_func in PARSERS:
         try:
-            links = list(parser_func(to_parse))
-            if links:
-                timer.end()
-                return links, parser_name
-        except Exception as err:   # noqa
-            pass
+            parsed_links = list(parser_func(to_parse, root_url=root_url))
+            if not parsed_links:
+                raise Exception('no links found')
+
+            # print(f'[√] Parser {parser_name} succeeded: {len(parsed_links)} links parsed')
+            if len(parsed_links) > len(most_links):
+                most_links = parsed_links
+                best_parser_name = parser_name
+                
+        except Exception as err:                                                # noqa
             # Parsers are tried one by one down the list, and the first one
             # that succeeds is used. To see why a certain parser was not used
             # due to error or format incompatibility, uncomment this line:
+            
             # print('[!] Parser {} failed: {} {}'.format(parser_name, err.__class__.__name__, err))
             # raise
+            pass
+    timer.end()
+    return most_links, best_parser_name
 
 
 @enforce_types
@@ -126,15 +141,11 @@ def save_file_as_source(path: str, timeout: int=TIMEOUT, filename: str='{ts}-{ba
 
     if any(path.startswith(s) for s in ('http://', 'https://', 'ftp://')):
         # Source is a URL that needs to be downloaded
-        print('{}[*] [{}] Downloading {}{}'.format(
-            ANSI['green'],
-            datetime.now().strftime('%Y-%m-%d %H:%M:%S'),
-            path,
-            ANSI['reset'],
-        ))
+        print(f'    > Downloading {path} contents')
         timer = TimedProgress(timeout, prefix='      ')
         try:
             raw_source_text = download_url(path, timeout=timeout)
+            raw_source_text = htmldecode(raw_source_text)
             timer.end()
         except Exception as e:
             timer.end()
